<?php
class MWC_ID_List_Table extends WP_List_Table {

	public $query;
	public $total_item_count;
	public $eyecatch_view = false;
	public $view_post_id = false;
	public $hidden_columns = array();

	/**
	 * Constructor, we override the parent to pass our own arguments
	 * We usually focus on three parameters: singular and plural labels, as well as whether the class supports AJAX.
	 */
	function __construct() {
		parent::__construct(array(
			'singular'=> 'wp_list_text_link', //Singular label
			'plural' => 'wp_list_test_links', //plural label, also this well be one of the table css class
			'ajax'	=> false //We won't support Ajax for this table
		));
	}

	/**
	 * Define the columns that are going to be used in the table
	 * @return array $columns, the array of columns to use with the table
	 */
	public function get_columns() {
		return $columns= array(
			'count'=>'拍手数',
			'label'=> 'ページ',
		);
	}

	public function column_count($item) {
		return '<span>'. $item->count. '</span>';
	}

	public function column_label($item) {
		$output = '<a href="'. get_permalink($item->post_id). '" target="_blank">';
		if ($this->view_post_id) {
			$item->label = '('. $item->post_id. ') '. $item->label;
		}
		$output .= esc_attr($item->label);
		if ($this->eyecatch_view) {
			if ($this->view_post_id) {
				$output .= '<br>';
			}
			$output .= get_the_post_thumbnail($item->post_id, array(150, 150));
		}
		$output .= '</a>';
		return $output;
	}

	/**
	* Define which columns are hidden
	*
	* @return Array
	*/
	public function get_hidden_columns() {
		return $this->hidden_columns;
	}

	public function add_hidden_columns($col) {
		array_push($this->hidden_columns, $col);
	}

	/**
	 * Decide which columns to activate the sorting functionality on
	 * @return array $sortable, the array of columns that can be sorted by the user
	 */
	public function get_sortable_columns() {
		return $sortable = array(
			'count' => array('count', false),
			'label' => array('label', false),
		);
	}

	public function column_default($item, $column_name){
		return $item->$column_name;
	}

	/**
	 * Prepare the table with different parameters, pagination, columns and table elements
	 */
	public function prepare_items() {
		global $wpdb;

		$columns = $this->get_columns();
		$hidden = $this->get_hidden_columns();
		$sortable = $this->get_sortable_columns();

		/* -- Ordering parameters -- */
		$query = $this->query;
		$orderby = (isset($_GET["orderby"]) && in_array($_GET["orderby"], array_keys($columns))) ? $_GET["orderby"] : 'count';
		$order = (isset($_GET["order"]) && in_array($_GET["order"], array('asc', 'desc'))) ? strtoupper($_GET["order"]) : 'DESC';
		$query .=' ORDER BY '. $orderby. ' '. $order;

		/* -- Pagination parameters -- */
		$data = $wpdb->get_results($query); //return the total number of affected rows

		// usort($data, array(&$this, 'sort_data'));

		$perpage = 20;
		$currentpage = $this->get_pagenum();
		$total = count($data);
		$this->total_item_count = $total;

		$this->set_pagination_args(array(
			'total_items' => $total,
			'per_page'    => $perpage
		));

		$totalitems = array_slice($data, (($currentpage-1) * $perpage), $perpage);

		$this->_column_headers = array($columns, $hidden, $sortable);
		$this->items = $totalitems;
	}
}
