<?php
/*
Plugin Name: Maroyaka WebClap for WordPress
Plugin URI: http://mcgi.jpn.ch/
Description: まろやかWEB拍手 for WordPress
Author: tisa
Version: 1.4
Author URI: http://mcgi.jpn.ch/
*/

define('MWC_DB_TABLE_ID', 'mwc_id');
define('MWC_DB_TABLE_CLAP', 'mwc_clap');
define('MWC_DB_TABLE_MESSAGES', 'mwc_messages');

define('MWC_PRIORITY_NUM', 10);
define('MWC_CAPABILITY', 'edit_pages');

define('MWC_PLUGIN', __FILE__);
define('MWC_PLUGIN_DIR', untrailingslashit(dirname(__FILE__)));
define('MWC_PLUGIN_URL', untrailingslashit(plugins_url('', __FILE__)));

require_once MWC_PLUGIN_DIR. '/common.php';

class MaroyakaWebClap {
	protected $pnop = array();
	protected $prefix;
	protected $db;
	protected $version;

	function __construct() {
		global $wpdb;
		$this->db = $wpdb;
		$this->prefix = self::get_prefix();

		$data = get_file_data(MWC_PLUGIN, array('version' => 'Version'));
		$this->version = $data['version'];

		$this->pnop = get_option('mwc_config');

		if (function_exists('register_activation_hook')) register_activation_hook(MWC_PLUGIN, array($this, 'activation'));
		if (function_exists('register_uninstall_hook')) register_uninstall_hook(MWC_PLUGIN, array('MaroyakaWebClap', 'uninstall'));
	}

	///////////////////////////////////////
	/* テーブル生成 */
	///////////////////////////////////////
	private function create_table($table_name, $schema) {
		$tn = $this->prefix. $table_name;
		if ($this->db->get_var("SHOW TABLES LIKE '". $tn. "'") != $tn) {
			dbDelta("CREATE TABLE ". $tn. " (". $schema. "); ");
		}
	}

	///////////////////////////////////////
	/* インストール */
	///////////////////////////////////////
	public function activation() {
		require_once(ABSPATH . 'wp-admin/includes/upgrade.php');

		// IDテーブル
		$id_table_schema = "
			id INTEGER NOT NULL AUTO_INCREMENT,
			post_id INTEGER NOT NULL,
			count INTEGER NOT NULL,
			label VARCHAR(500),
			PRIMARY KEY id (id),
			INDEX idx_1(post_id)
		";
		$this->create_table(MWC_DB_TABLE_ID, $id_table_schema);

		// 拍手テーブル
		$clap_table_schema = "
			id INTEGER NOT NULL AUTO_INCREMENT,
			post_id INTEGER NOT NULL,
			ip VARCHAR(16) NOT NULL,
			timestamp TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
			PRIMARY KEY id (id),
		  INDEX idx_1 (post_id),
		  INDEX idx_2 (timestamp, post_id, id)
		";
		$this->create_table(MWC_DB_TABLE_CLAP, $clap_table_schema);

		// メッセージテーブル
		$msg_table_schema = "
			id INTEGER NOT NULL AUTO_INCREMENT,
			clap_id INTEGER NOT NULL,
			set_phrases VARCHAR(500),
			name VARCHAR(255),
			message TEXT(1000) NOT NULL,
			PRIMARY KEY id (id),
			INDEX idx_1(clap_id)
		";
		$this->create_table(MWC_DB_TABLE_MESSAGES, $msg_table_schema);

		// オプションデフォルト設定
		$default_config = array(
			'btn_locate_single' => 1,
			'btn_locate_page' => 1,
			'btn_locate_loop' => 0,
			'btn_align' => 'left',
			'btn_text' => 'WEB拍手',
			'btn_type' => 'normal',
			'btn_color' => 'default',
			'btn_count_view' => 1,
			'max_claping' => 5,
			'reclap_time' => 24,
			'thanks_msg' => '拍手ありがとうございます！よろしければメッセージをどうぞ！',
			'name_input' => 1,
			'set_phrases_select' => 1,
			'message_input' => 1,
			'set_phrases' => array('頑張ってください！', '陰ながら応援しています！', '密かなファンです！'),
			'deny_ips' => array(),
			'mail_notice_name' => null,
			'mail_notice_sp' => null,
			'mail_notice_msg' => null,
			'mailaddress' => null,
		);
		add_option('mwc_config', $default_config);
	}

	///////////////////////////////////////
	/* アンインストール */
	///////////////////////////////////////
	public static function uninstall() {
		global $wpdb;
		$prefix = self::get_prefix();
		// データベーステーブル削除
		$wpdb->query("DROP TABLE ". $prefix. MWC_DB_TABLE_ID);
		$wpdb->query("DROP TABLE ". $prefix. MWC_DB_TABLE_CLAP);
		$wpdb->query("DROP TABLE ". $prefix. MWC_DB_TABLE_MESSAGES);
		// オプション削除
		delete_option('mwc_config');
		delete_option('mwc_ranking');
	}

	///////////////////////////////////////
	/* 接頭辞取得 */
	///////////////////////////////////////
	public static function get_prefix() {
		global $wpdb;
		return $wpdb->get_blog_prefix((defined('BLOG_ID_CURRENT_SITE')) ? BLOG_ID_CURRENT_SITE : '');
	}

	///////////////////////////////////////
	/* 設定値取得 */
	///////////////////////////////////////
	protected function get_option($name, $default = null) {
		$value = null;
		if (isset($this->pnop[$name])) {
			$value = $this->pnop[$name];
		} else if ( ! is_null($default)) {
			$value = $default;
		}
		return $value;
	}

	///////////////////////////////////////
	/* POSTパラメータ取得 */
	///////////////////////////////////////
	protected function get_post($str, $def = null) {
		$value = null;
		if (isset($_POST[$str])) {
			$value = $_POST[$str];
		} else if ( ! is_null($def)) {
			$value = $def;
		}
		return $value;
	}

	///////////////////////////////////////
	/* GETパラメータ取得 */
	///////////////////////////////////////
	protected function get_query($str, $def = null) {
		$value = null;
		if (isset($_GET[$str])) {
			$value = $_GET[$str];
		} else if ( ! is_null($def)) {
			$value = $def;
		}
		return $value;
	}
}
